# Testfiles

This is a collection of various auxilary files that testcases may use as input.
Such as `fio` jobfiles.

The absolute path to this directory is defined as environment variable:

```bash
CIJ_TESTFILES=$CIJ_PKG_ROOT/testfiles
```
